ExpandMsgXmdError

Enum ExpandMsgXmdError 

pub enum ExpandMsgXmdError {
    EmptyDst,
    DstHash,
    Length,
}
Error type for ExpandMsgXmd.

Variants



EmptyDst

The domain separation tag must not be empty.



DstHash

The hash’s output size must not be greater then 255 if the domain separation tag is longer than 255.



Length

The length in bytes is too large.

len_in_bytes must be at most 255 * HashT::OutputSize.