pub trait Expander {
// Required method
fn fill_bytes(&mut self, okm: &mut [u8]) -> Result<usize, Error>;
}Expand description
Expander that, call read until enough bytes have been consumed.
pub trait Expander {
// Required method
fn fill_bytes(&mut self, okm: &mut [u8]) -> Result<usize, Error>;
}Expander that, call read until enough bytes have been consumed.